@@ -4,7 +4,7 @@ from python_compose.unit.conda import CondaUnit
 compose.compose(
     [
         CondaUnit(
-            name=f"httpd_{i}", requirements=[], script=["python3", "httpd.py", str(8080 + i)]
+            name=f"httpd_{i}", requirements=[], command=["python3", "httpd.py", str(8080 + i)]
         )
         for i in range(3)
     ]
